@@ -2,8 +2,8 @@
                           main.cpp  -  description
                              -------------------
     begin                : December 2007
-    copyright            : (c) 2007 by Roland Suchan
-    email                : vmp@arcor.de
+    copyright            : (c) 2007 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
     license              : GPL v 2.0
  ***************************************************************************/
 
@@ -70,14 +70,14 @@ int main(int argc, char **argv)
 		Q_VERSION,                                          // The program version string.
 		ki18n(Q_DESCRIPTION),                               // A short description of what the program does.
 		KAboutData::License_GPL,                            // License identifier
-		ki18n("Copyright (c) 2007-2010 Roland Suchan"),     // Copyright Statement
+		ki18n("Copyright (c) 2007-2012 Iven Wold"),     // Copyright Statement
 		ki18n(""),                                          // Some free form text, that can contain any kind of information.
 		"",                                                 // The program homepage string.
 		"submit@bugs.kde.org");                             // The bug report email address string.
 
 	//aboutData->addAuthor( ki18n("Matteo Merli"), ki18n("Original author"), "merlim@libero.it" );
-	aboutData->addAuthor( ki18n("Roland Suchan"), KLocalizedString(), "vmp@arcor.de" );
-	//aboutData->addAuthor( ki18n("Roland Suchan"), ki18n("KDE 4 changes"), "vmp@arcor.de" );
+	aboutData->addAuthor( ki18n("Iven Wold"), KLocalizedString(), "hour.glass2@yahoo.com" );
+	//aboutData->addAuthor( ki18n("Iven Wold"), ki18n("KDE 4 changes"), "hour.glass2@yahoo.com" );
 	aboutData->addCredit( ki18n("Matteo Merli"), ki18n("qtrans 0.1.1 for KDE 2"), "merlim@libero.it" );
 	aboutData->addCredit(ki18n("Frederic Jolliton"), ki18n("Babylon library"), "fjolliton@free.fr");
 
