@@ -5,8 +5,8 @@
 
                              -------------------
     begin                : February 2009
-    copyright            : (c) 2007 by Roland Suchan
-    email                : vmp@arcor.de
+    copyright            : (c) 2007 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
     license              : GPL v 2.0
  ***************************************************************************/
 
@@ -35,6 +35,7 @@
 #include <QDebug>	//ooo
 #include <QUrl>		//ooo
 #include <QDir>		//ooo
+#include <QTextCodec>	//ooo
 
 #include <iostream>	//ooo
 #include <stdlib.h>	//ooo
@@ -42,22 +43,18 @@
 #include <stdio.h>	//ooo
 
 #include "babylon_bgl.h"
-
-//#define DEBUG_1
-//#define DEBUG_2
-//#define DEBUG_3
-//#define DEBUG_3a
-//#define DEBUG_3a_
-//#define DEBUG_3b
-//#define DEBUG_3h
-//#define DEBUG_3p
-//#define DEBUG_4
-//#define DEBUG_5
+#include "utils.h"
 
 
-Babylon_bgl::Babylon_bgl(QString filename, QString strIndexDir)
+Babylon_bgl::Babylon_bgl(QString filename, QString strIndexDir, QString word, bool enableAlternates, int encodingExpression_id)
 {
 	m_filename = filename.toAscii().data();
+	b_enableAlternates = enableAlternates;
+	i_encodingExpression_id = encodingExpression_id;
+	//m_word1 = word.toAscii().data();
+	mq_word = word;
+	m_word1 = word.toAscii().data();
+	m_word = std::wstring(m_word1.begin(), m_word1.end());
 
 	//ba = filename.toStdString().c_str();
 
@@ -125,10 +122,6 @@ bool Babylon_bgl::open()
 
 	fclose( f );
 
-#ifdef DEBUG_1
-	qDebug() << "Babylon_bgl::open()";
-#endif
-
 	return true;
 
 /*	QFile file(m_filename);
@@ -144,53 +137,25 @@ bool Babylon_bgl::open()
 bool Babylon_bgl::readBlock( bgl_block &block )
 {
 
-	#ifdef DEBUG_1
-		if ( &block != NULL) {
-			qDebug() << ">>> ...........................";
-			qDebug() << "Babylon_bgl::readBlock( bgl_block &block )" << " block.length = " << block.length; 
-		} else {
-			qDebug() << "&block = NULL";
-		}
-	#endif
-
 	if( gzeof( file ) || file == NULL ) {
-		#ifdef DEBUG_1
-			qDebug() << "if( gzeof( file ) || file == NULL ) {";
-		#endif
 		return false;
 	}
 
 	block.length = bgl_readnum( 1 );
 	block.type = block.length & 0xf;
 
-	#ifdef DEBUG_1
-		qDebug() << "block.type = " << "(block.length & 0xf)";
-	#endif
-
 	if( block.type == 4 ) {
-		#ifdef DEBUG_1
-			qDebug() << "block.type == 4";
-		#endif
 		return false; // end of file marker
 	}
 	block.length >>= 4;
 	block.length = block.length < 4 ? bgl_readnum( block.length + 1 ) : block.length - 4 ;
 
 	if( block.length ) {
-
-		#ifdef DEBUG_1
-			qDebug() << "------ if( " << block.length << ") {";
-		#endif
-
 		//block.data = (char *)malloc( block.length );
 		block.data = (unsigned char *)malloc( block.length );	//ooo
 		gzread( file, block.data, block.length );
 	}
 
-	#ifdef DEBUG_1
-		qDebug() << "........................... <<<";
-	#endif
-
 	return true;
 }
 
@@ -221,10 +186,6 @@ bool Babylon_bgl::read()
 	m_numEntries = 0;
 	while( readBlock( block ) ) {
 
-		#ifdef DEBUG_1
-			qDebug() << "            >>> while( readBlock( block ) ) { <<<" << " block.type = " << "(block.length & 0xf)";
-		#endif
-
 		headword.clear();
 		definition.clear();
 		switch( block.type ) {
@@ -233,10 +194,6 @@ bool Babylon_bgl::read()
 					case 8:
 						type = (uint)block.data[2];
 
-						#ifdef DEBUG_2
-							qDebug() << " type = " << type;
-						#endif
-
 						if( type > 64 ) type -= 65;
 						m_defaultCharset = bgl_charset[type];
 						break;
@@ -314,10 +271,6 @@ bool Babylon_bgl::read()
 	//convertToUtf8( m_copyright, DEFAULT_CHARSET );
 	//convertToUtf8( m_description, DEFAULT_CHARSET );
 
-	#ifdef DEBUG_1
-		qDebug() << "Babylon_bgl::read()";
-	#endif
-
 	return true;
 }
 
@@ -367,6 +320,12 @@ bgl_entry Babylon_bgl::readEntry()
 	QDir dir;			//ooo
 	QDir hashDir;			//ooo
 	bool dirWasCreated = false;	//ooo
+	int j = 0;			//ooo
+	//std::string temp_head = "";	//ooo
+	
+	QString wordExpressionString;
+	QByteArray encodedWordExpressinString;
+	QTextCodec *languageCodec;
 	
 	hash.reset();					//ooo
 	hash.addData( ba );				//ooo
@@ -384,14 +343,14 @@ bgl_entry Babylon_bgl::readEntry()
 		dir.mkpath( hash.result().toHex() );
 		dirWasCreated = true;
 	}
+	
+	languageCodec = QTextCodec::codecForName(Codec[i_encodingExpression_id].toLatin1());
 
 
 	while( readBlock( block ) )
 	{
-
-		#ifdef DEBUG_2
-			//qDebug() << "   >>> Babylon_bgl::readEntry() --- " << "block.type = " << block.type;
-		#endif
+		std::string temp_head = "";	//ooo
+		QString qs_head = "";		//ooo
 
 		switch( block.type )
 		{
@@ -400,12 +359,6 @@ bgl_entry Babylon_bgl::readEntry()
 
 				pos = 0;
 
-				#ifdef DEBUG_3b
-					std::wcout << "\n222\n";
-					std::wcout << "block.data[" << pos << "] = " << block.data[pos] << "\n";
-				#endif
-
-
 				len = (unsigned char)block.data[pos++];
 
 				//std::string filename( block.data+pos, len );
@@ -417,18 +370,9 @@ bgl_entry Babylon_bgl::readEntry()
 
 				for ( unsigned int i = pos; i < pos + len; i++) {
 
-					#ifdef DEBUG_3b
-						std::wcout << "block.data[" << i << "] = " << block.data[i] << "\n";
-					#endif
-
 					 filename += block.data[i];
 				}
 
-				#ifdef DEBUG_3b
-					//std::wcout << "filename = " << filename << "\n";
-					std::cout << "filename = " << filename << "\n";
-				#endif
-
 				pos += len;
 
 				/*unsigned char const * data = &block.data[pos];
@@ -445,16 +389,6 @@ bgl_entry Babylon_bgl::readEntry()
 
 				compressedSize = compressedData.size();
 
-				#ifdef DEBUG_3p
-					//FILE *fp = fopen(filename.c_str(), "w");
-					fp = fopen(filename.c_str(), "w");
-					//fwrite(block.data + pos, 1, block.length -pos, fp);
-					//fwrite(&compressedData.front(), 1, size, fp);
-					fwrite(&block.data[pos], 1, size, fp);
-					fclose(fp);
-				#endif
-				
-
 				if (dirWasCreated) {	//ooo
 					//filename_2 = "/home/gons/.qtrans/index/" + hash_str + "/" + filename;
 					 filename_2 = std::string(m_qstrIndexDir.toAscii().data()) + "/" + hash_str + "/" + filename;
@@ -476,20 +410,12 @@ bgl_entry Babylon_bgl::readEntry()
 
 				/*if (filename == "D437C11D.bmp") {
 
-					#ifdef DEBUG_3b
-						std::cout << "***   D437C11D.bmp" << "\n";
-					#endif
-
 				}*/
 
 				break;
 			case 1:
 			case 10:
 
-				#ifdef DEBUG_2
-					qDebug() << "   case 10 ";
-				#endif
-
 				alternate.clear();
 				headword.clear();
 				definition.clear();
@@ -503,21 +429,53 @@ bgl_entry Babylon_bgl::readEntry()
 				len = (unsigned char)block.data[pos++];
 
 				headword.reserve( len );
-				for(uint a=0;a<len;a++) headword += block.data[pos++];
+				//for(uint a = 0; a < len; a++) headword += block.data[pos++];
+				for (uint a = 0; a < len; a++) {
+					
+					/*if ( block.data[pos] == 232 ) {
+						//headword += 269;
+						headword += 0xC4;
+						headword += 0x8D;
+						//headword += 196;
+						//headword += 141;
+						pos++;
+					} else {*/
+						headword += (unsigned char)block.data[pos++];	//ooo
+// 					/*}*/
+				}
 				//convertToUtf8( headword, SOURCE_CHARSET );
 
-
 				//j = headword.find("black");
-
-				#ifdef DEBUG_3a
-					std::cout << "\n......................\n";
-					std::wcout << "block.data[" << pos << "] = " << block.data[pos] << "\n";
-					std::wcout << "block.data[" << pos+1 << "] = " << block.data[pos+1] << "\n";
-					std::wcout << "block.data[" << pos+2 << "] = " << block.data[pos+2] << "\n";
-					//printf("Headword : %s\n", headword.c_str());
-					//printf("Definition to ...: %s\n", entry.definition.c_str());
-					//printf("Definition to ...: %s\n", "	*****");
-				#endif
+				//j = headword.find(m_word);
+				//if ( j != std::wstring::npos ) continue;
+				
+				if ( !b_enableAlternates ) {
+				  
+					//std::copy(headword.begin(), headword.end(), std::back_inserter(temp_head));	//ooo
+					   //j = temp_head.find(m_word1);
+					   //if ( j < 0 ) continue;
+					//qs_head = temp_head.c_str();
+					
+					//qs_head = QString::fromWCharArray(entry.headword.data(), int(entry.headword.size()));		//ooo
+					qs_head = QString::fromWCharArray(headword.data(), int(headword.size()));			//ooo
+					
+					if ( i_encodingExpression_id != 0 ) {								//ooo
+					  
+						//qs_head = QString::fromWCharArray(headword.data(), int(headword.size()));		//ooo
+						encodedWordExpressinString = qs_head.toLatin1();
+						wordExpressionString = languageCodec->toUnicode(encodedWordExpressinString);
+						
+						if (!wordExpressionString.contains(mq_word, Qt::CaseInsensitive)) continue;
+						
+					} else {
+					  
+						if (!qs_head.contains(mq_word, Qt::CaseInsensitive)) continue;
+						
+					}
+					
+					//if (!qs_head.contains(mq_word, Qt::CaseInsensitive)) continue;
+					//if (!wordExpressionString.contains(mq_word, Qt::CaseInsensitive)) continue;
+				}
 
 				// Definition
 				len = 0;
@@ -525,61 +483,20 @@ bgl_entry Babylon_bgl::readEntry()
 				//pos++;						//ooo
 				//len = (unsigned char)block.data[pos++];		//ooo
 
-				#ifdef DEBUG_3a
-					std::wcout << "len = " << len << "\n";
-				#endif
-
 				//len <<= 8;					//ooo
 
-				#ifdef DEBUG_3a
-					std::wcout << "len = " << len << "\n";
-				#endif
-
 				len |= (unsigned char)block.data[pos++];
 				definition.reserve( len );
 
-				#ifdef DEBUG_3a
-					//std::cout << "\n......................\n";
-					std::wcout << "headword = " << headword << "\n";
-					std::wcout << "len = " << len << "\n";
-				#endif
-
-				for(uint a=0;a<len;a++)
-				{
-					#ifdef DEBUG_3a_
-						std::wcout << "block.data[" << pos << "] = " << block.data[pos] << " a = " << a << "\n";
-					#endif
-
-					#ifdef DEBUG_3a
-						//qDebug() << "   for(uint a=0;a<len;a++) --- a = " << a;
-						//qDebug() << "block.data[" << pos << "] = " << block.data[pos];
-
-						/*if ( headword.compare(L"Afro-Asian $1$") == 0 ) {
-							std::wcout << "block.data[" << pos << "] = " << block.data[pos] << "\n";
-						}*/
-
-						//std::wcout << "block.data[" << pos << "] = " << block.data[pos] << " a = " << a << "\n";
-
-						definition_origin += block.data[pos];
-
-					#endif
+				for (uint a = 0; a < len; a++) {
 
 					if ( (unsigned char)block.data[pos] == 0x0a ) {		//LF: LineFeed
 
-						#ifdef DEBUG_2
-							qDebug() << "block.data[" << pos << "] == 0x0a = " << block.data[pos];
-						#endif
-
 						definition += '\n';
 						pos++;
 
 					} else if ( (unsigned char)block.data[pos] == 0x06 ) {
 
-						#ifdef DEBUG_3a
-							std::wcout << "block.data[" << pos+1 << "] = " << block.data[pos+1] << "\n";
-							std::wcout << "block.data[" << pos+2 << "] = " << block.data[pos+2] << "\n";
-						#endif
-
 						pos += 2;
 						a++;
 
@@ -596,10 +513,6 @@ bgl_entry Babylon_bgl::readEntry()
 
 						// definition = def + head
 
-						#ifdef DEBUG_3
-							std::cout << "\n>>>>>> (x?)\n";
-						#endif
-
 						// length of the explanation string	(Ita->Eng)
 						unsigned int length = (unsigned char)block.data[ pos + 1 ];
 
@@ -609,11 +522,6 @@ bgl_entry Babylon_bgl::readEntry()
 							headword += block.data[i];
 						}
 
-						#ifdef DEBUG_5
-							definition += std::wstring( L"(\?\?)" )
-							//definition += L"(??)";
-						#endif
-
 						pos += length + 2;
 						a += length + 1;
 
@@ -622,10 +530,6 @@ bgl_entry Babylon_bgl::readEntry()
 						//replace headword through headword explanation which is placed at the end of definition
 						// Ab$3$ <- Ab...
 
-						#ifdef DEBUG_3a
-							std::cout << "\n>>>>>> (xx?)\n";
-						#endif
-
 						// length of the explanation string
 						unsigned int length = (unsigned char)block.data[ pos + 1 ];
 
@@ -642,10 +546,6 @@ bgl_entry Babylon_bgl::readEntry()
 
 						//replace headword through headword explanation which is placed at the begining of definition
 
-						#ifdef DEBUG_3a
-							std::cout << "\n>>>>>> (xxx?)\n";
-						#endif
-
 						// length of the explanation string
 						unsigned int length = (unsigned char)block.data[ pos + 1 ];
 
@@ -662,10 +562,6 @@ bgl_entry Babylon_bgl::readEntry()
 
 						//replace headword through headword explanation which is placed at the end of definition
 
-						#ifdef DEBUG_3a
-							std::cout << "\n>>>>>> (xxxx?)\n";
-						#endif
-
 						// length of the explanation string
 						unsigned int length = (unsigned char)block.data[ pos + 1 ];
 
@@ -707,10 +603,6 @@ bgl_entry Babylon_bgl::readEntry()
 					} else if ( (unsigned char)block.data[pos] == 0x50 && (unsigned char)block.data[pos + 1 ] == 0x1B &&
 							len - a - 1 >= 2 ) {
 
-						#ifdef DEBUG_3a
-							std::cout  << "\n*** transcription (1)\n";
-						#endif
-
 						unsigned int length = (unsigned char)block.data[pos + 2 ];
 
 						for ( unsigned int i = (pos+3); i < (pos+3+length); i++) {
@@ -739,10 +631,6 @@ bgl_entry Babylon_bgl::readEntry()
 					} else if ( (unsigned char)block.data[pos] == 0x60 && (unsigned char)block.data[pos + 1 ] == 0x1B &&
 							len - a - 1 >= 2 ) {
 
-						#ifdef DEBUG_3a
-							std::cout  << "\n*** transcription (2)\n";
-						#endif
-
 						unsigned int length = (unsigned char)block.data[pos + 2 ];
 
 						length <<= 8;
@@ -786,10 +674,6 @@ bgl_entry Babylon_bgl::readEntry()
 
 						//hash_str = hash.result().toHex().data();
 
-						#ifdef DEBUG_3h
-							std::cout << "hash_str = " << hash_str << "\n";
-						#endif
-
 						/*++pos;
 
 						while ( (unsigned char)block.data[pos] != 0x1F ) {
@@ -834,24 +718,10 @@ bgl_entry Babylon_bgl::readEntry()
 
 					} else if ( (unsigned char)block.data[pos] < 0x20 ) {	//SP: Space
 
-						#ifdef DEBUG_2
-							qDebug() << "block.data[" << pos << "] < 0x20 = " << block.data[pos];
-						#endif
-
 						if ( a <= /*<*/ len - 3 && block.data[pos] == 0x14 && block.data[pos+1] == 0x02 ) {
 
-							#ifdef DEBUG_3a
-								std::wcout << "block.data[" << pos+1 << "] = " << block.data[pos+1] << "\n";
-								std::wcout << "block.data[" << pos+2 << "] = " << block.data[pos+2] << "\n";
-							#endif
-
 							//definition = partOfSpeech[(unsigned char)block.data[pos+2] - 0x30] + " " + definition;
 							definition = partOfSpeech[(unsigned char)block.data[pos+2] - 0x30] + L" " + definition;	//ooo
-
-							#ifdef DEBUG_5
-								//definition = partOfSpeech[(unsigned char)block.data[pos+2] - 0x30] + L" " + definition + L"(?)";		//ooo
-								definition += L"(?)";		//ooo
-							#endif
 						//}
 
 
@@ -871,49 +741,6 @@ bgl_entry Babylon_bgl::readEntry()
 
 					} else {
 
-						#ifdef DEBUG_3a
-
-							 //size_t end = current_section.rfind(L']');
-							//const std::wstring toFind = L"Acheulian";
-							//std::wstring::size_type n = 0;
-							 //toFind = L"Acheulian";
-
-
-							/*while((pos = headword.find(toReplace, pos)) != std::wstring::npos) {
-								result.replace(pos, toReplace.length(), replaceWith);
-								pos += replaceWith.length();
-							}*/
-
-							//std::cout << "pos = " << pos << "\n";
-							//std::cout << "headword.find(toFind, pos_) = " << headword.find(toFind, n) << "\n";
-							//std::cout << "std::wstring::npos = " << std::wstring::npos << "\n";
-
-							//for(wstring::size_type i = text.find(L'\n'); i != wstring::npos; i = text.find(L'\n', ++i))
-							//while ((n = definition.find('Acheulian', n)) != std::wstring::npos) {
-							/*for ( n = headword.find(toFind); n != std::wstring::npos; n = headword.find(toFind, ++n)) {
-
-								if (n > 0) {
-									std::cout << " n = " << n << "* * * * * *\n";
-								}
-								std::cout << "n = " << n << "\n* * * * * *\n";
-								n++;
-							}*/
-
-							//if( std::wstring(your_char_ptr_string) == your_wstring)
-							/*if( std::wstring(L"Acheulian") == headword) {
-								std::cout << "\n* * * * * *\n";
-							}*/
-
-							/*if (headword.find(L"Mitler") < headword.size() ){
-								std::cout << "*";
-							}*/
-
-							/*if ((block.data[pos] == 0x31)
-								&& (block.data[pos+1] == 0x39) && (block.data[pos+2] == 0x33) && (block.data[pos+4] == 0x33)) {
-								std::wcout << "bloc.data[" << pos+1 << "]" << "\n";
-							}*/
-						#endif
-
 						if (block.data[pos] == 0x96 && ( (block.data[pos+1] >= 0x30 && block.data[pos+1] <= 0x39) ||
 							(block.data[pos+1] >= 0x41 && block.data[pos+1] <= 0x5A) ||
 							(block.data[pos+1] >= 0x61 && block.data[pos+1] <= 0x7A))) {	//ooo but eng->jpn problem
@@ -927,64 +754,28 @@ bgl_entry Babylon_bgl::readEntry()
 						}
 
 						//definition += block.data[pos++];
-
-						#ifdef DEBUG_1
-							//qDebug() << "definition = " << block.data[pos+1];
-							qDebug() << "block.data[pos+1] = " << block.data[pos+1];
-						#endif
 					}
 
 					//int place = definition.find("black");
 
 					//if (definition.find("black") != -1) {
 					//if (place >= 0) {
-						#ifdef DEBUG_4
-							//printf("Definition to black: \n%s\n", "	###");
-							printf("Definition to black: %i\n", place);
-							qDebug() << "block.data[" << pos-15 << "] = " << (int)block.data[pos-15] << " chair = " << block.data[pos-15];
-						#endif
 					//}
 
 				}
 				//convertToUtf8( definition, TARGET_CHARSET );
 
-				#ifdef DEBUG_2
-					//qDebug() << "alternate = " << QString(" %1 ").arg(alternate.data());
-					qDebug() << "block.length = " << block.length;
-				#endif
-
 				// Alternate forms
 				while ( pos != block.length ) {
 					len = (unsigned char)block.data[pos++];
 					alternate.reserve( len );
-					for(uint a=0;a<len;a++) alternate += block.data[pos++];
+					for (uint a = 0; a < len; a++) alternate += block.data[pos++];
 					//convertToUtf8( alternate, SOURCE_CHARSET );
 
-					#ifdef DEBUG_2
-						qDebug() << "alternate = " << QString(" %1 ").arg(alternate.data());
-					#endif
-
 					alternates.push_back( alternate );
 					alternate.clear();
 				}
 
-				#ifdef DEBUG_3
-					if ( (n = headword.find(toFind)) != std::wstring::npos) {
-						std::cout  << "\n########################################\n";
-						std::wcout << "headword = " << headword << "\n";
-						std::wcout << "definition = " << definition << "\n";
-						std::cout  << "########################################\n";
-					}
-
-					if ( (n = definition.find(toFind_x2)) != std::wstring::npos) {
-						std::wcout << "block.data[" << n << "] = " << block.data[n] << "\n";
-						std::wcout << "block.data[" << n + 9 << "] = " << block.data[n+9] << "\n";
-						std::wcout << "block.data[" << n + 10 << "] = " << block.data[n+10] << "\n";
-						std::wcout << "block.data[" << n + 11 << "] = " << block.data[n+11] << "\n";
-					}
-
-				#endif
-
 				entry.headword = headword;
 				entry.definition = definition;
 
@@ -1001,69 +792,17 @@ bgl_entry Babylon_bgl::readEntry()
 					entry.definition = definition_stack;
 				}*/
 
-				#ifdef DEBUG_3
-					std::cout << "n = " << definition_origin.find(L"") << "\n";
-				#endif
-
 				//if ( (n = definition_stack.find(L"")) == std::wstring::npos) {
 				/*if ( definition_stack.empty()) {
 
-					#ifdef DEBUG_3a
-						std::wcout << "definition_stack (1) = " << definition_stack << "\n";
-					#endif
-
 					entry.definition = definition_stack;
 				} else {
 
-					#ifdef DEBUG_3a
-						std::wcout << "definition (2) = " << definition << "\n";
-					#endif
-
 					entry.definition = definition;
 				}*/
 
 				entry.alternates = alternates;
 
-				#ifdef DEBUG_3a
-				//if (entry.headword.compare("black") == 0 || entry.headword.compare("Black") == 0) {	//ooo
-				//if (entry.headword.find("black") < headword.size() || entry.headword.find("Black") < headword.size()) {	//ooo
-					//printf("Definition of ...: %s\n", entry.headword.c_str());
-					//printf("Definition of ...: %s\n", entry.definition.c_str());
-					//printf("Definition of ...: %s\n", "	*****");
-
-					/*std::copy(entry.headword.begin(), entry.headword.end(), std::back_inserter(temp));	//ooo
-
-					printf("Definition of ...: %s\n", temp.c_str());
-
-					std::copy(entry.definition.begin(), entry.definition.end(), std::back_inserter(temp));	//ooo
-
-					printf("Definition of ...: %s\n", temp.c_str());
-					printf("Definition of ...: %s\n", "	*****");*/
-
-					//const std::wstring toFind = L"Acheulian";
-					//std::wstring::size_type pos_x0 = 0;
-
-					/*for ( n = headword.find(toFind); n != std::wstring::npos; n = headword.find(toFind, ++n)) {
-
-						if (n > 0) {
-							std::cout << " n = " << n << "* * * * * *\n";
-						}
-						std::cout << " n = " << n << "\n* * * * * *\n";
-					}*/
-
-					/*if ( (n = headword.find(toFind)) != std::wstring::npos) {
-						std::cout  << "   ########################################\n";
-					}*/
-
-					std::wcout << "\ndefinition_origin = " << definition_origin << "\n";
-					std::wcout << "entry.headword = " << entry.headword << "\n";
-					std::wcout << "entry.definition = " << entry.definition << "\n";
-					std::cout  << "   *****\n";
-
-					//qDebug() << "D437C11D = " << QString::fromUtf8("D437C11D");
-				//}
-				#endif
-
 				return entry;
 
 				break;
@@ -1071,28 +810,11 @@ bgl_entry Babylon_bgl::readEntry()
 				;
 		}
 
-		#ifdef DEBUG_1
-
-			for ( n = headword.find(toFind); n != std::wstring::npos; n = headword.find(toFind, ++n)) {
-
-				if (n > 0) {
-					std::cout << " n = " << n << "* * * * * *\n";
-				}
-				std::cout << " n = " << n << "\n* * * * * *\n";
-			}
-
-			qDebug() << "   free( block.data ) ";
-		#endif
-
 		if( block.length ) free( block.data );
 	}
 
 	entry.headword = L"";
 
-	#ifdef DEBUG_2
-		qDebug() << "   Babylon_bgl::readEntry() >>> ";
-	#endif
-
 	return entry;
 }
 
