@@ -5,8 +5,8 @@
 
                              -------------------
     begin                : February 2009
-    copyright            : (c) 2007 by Roland Suchan
-    email                : vmp@arcor.de
+    copyright            : (c) 2007 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
     license              : GPL v 2.0
  ***************************************************************************/
 
@@ -192,7 +192,7 @@ typedef struct {
 
 class Babylon_bgl {
 public:
-	Babylon_bgl(QString filename, QString strIndexDir);
+	Babylon_bgl(QString filename, QString strIndexDir, QString word, bool enableAlternates, int encodingExpression_id);
 	~Babylon_bgl();
 
 	QString printMessage();
@@ -205,11 +205,16 @@ public:
 	std::string filename() const { return m_filename; };
 
 	std::string m_filename;
+	std::string m_word1;		//ooo
+	std::wstring m_word;		//ooo
+	QString mq_word;		//ooo
 	//QString m_filename;
 	QString m_qstrIndexDir;		//ooo
 	std::string m_strIndexDir;	//ooo
 	std::string h_filename;		//ooo
 	QByteArray ba;			//ooo
+	bool b_enableAlternates;	//ooo
+	int i_encodingExpression_id;	//ooo
 	gzFile file;
 
 private:
