@@ -3,8 +3,8 @@
 
                              -------------------
     begin                : 27. November 2009
-    copyright            : (c) 2007 by Roland Suchan
-    email                : vmp@arcor.de
+    copyright            : (c) 2007 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
     license              : GPL v 2.0
  ***************************************************************************/
 
@@ -55,21 +55,9 @@
 #define DICT_GZIP       2
 #define DICT_DZIP       3
 
-//#define DEBUG_1
-//#define DEBUG_1a
-//#define DEBUG_1b
-//#define DEBUG_1c
-//#define DEBUG_2
-//#define DEBUG_2a
-//#define DEBUG_3
 
 StarDict::StarDict(const QString &filename, bool wholeStarDict, bool wholeWordsOnly, bool wordStartsWith)
 {
-
-	#ifdef DEBUG_1
-		//std::cout.setf(std::ios_base::hex,std::ios_base::basefield);
-		std::cout << "StarDict::StarDict( )" << "\n";
-	#endif
 	
 	b_wholeStarDict = wholeStarDict;
 	b_wholeWordsOnly = wholeWordsOnly;
@@ -104,10 +92,6 @@ StarDict::StarDict(const QString &filename, bool wholeStarDict, bool wholeWordsO
 
 	ifoFile->close();
 
-	#ifdef DEBUG_1
-		std::cout << "StarDict::StarDict( ) (A)" << "\n";
-	#endif
-
 	QString file_holder_str = filename;
 
 	file_holder_str.replace( ".ifo", ".idx" );
@@ -129,10 +113,6 @@ StarDict::StarDict(const QString &filename, bool wholeStarDict, bool wholeWordsO
 			//m_isOk = false;
 			return;
 		}
-
-		#ifdef DEBUG_1
-			std::cout << "StarDict::StarDict( ) (B)" << "\n";
-		#endif
 	
 		// The definition file is compressed (.dict.dz)
 		// Read the header
@@ -141,26 +121,13 @@ StarDict::StarDict(const QString &filename, bool wholeStarDict, bool wholeWordsO
 
 		if (!dictFile->open(QIODevice::ReadOnly )) {
 			//return text = "error *.dict.dz";
-
-			#ifdef DEBUG_1
-				std::cout << "error *.dict.dz" << "\n";
-			#endif
-
 		}
 		
 		this->headerLength = GZ_XLEN - 1;	//ooo
 
-		#ifdef DEBUG_1
-			std::cout << "StarDict::StarDict( ) (C)" << "\n";
-		#endif
-
 		//ID1 = 31 (0x1f, \037)
 		dictFile->getChar(&c);
 
-		#ifdef DEBUG_1
-			std::cout << "StarDict::StarDict( ) (C: if)" << " ID1 = " << c << "\n";
-		#endif
-
 		if ( c != 0x1f ) {		//ooo
 			//m_isOk = false;
 			return;
@@ -169,67 +136,27 @@ StarDict::StarDict(const QString &filename, bool wholeStarDict, bool wholeWordsO
 		//ID2 = 139 (0x8b, \213)
 		dictFile->getChar(&c);
 		
-		#ifdef DEBUG_1
-			std::cout << "StarDict::StarDict( ) (D) ID2 = " << c << "\n";
-		#endif
-		
-		if ( (unsigned char)c != 0x8b ) {
-		 	
+		if ( (unsigned char)c != 0x8b ) {	
 			return;
-			
 		}
 
-		#ifdef DEBUG_1
-			std::cout << "StarDict::StarDict( ) (E)" << "\n";
-		#endif
-
 		// COMPRESSION
 		dictFile->getChar(&c);
 		CM = /*(unsigned char)*/c;
 
-		#ifdef DEBUG_1
-			std::cout << "StarDict::StarDict( ) (E: if)" << " CM = " << c << "(" << c - '0' << ")" <<"\n";
-		#endif
-
 		if ( c == 0x08 ) {
-			 
-			#ifdef DEBUG_1
-				std::cout << "StarDict::StarDict( ) (E: if->if): c == '0x08'" << "\n";
-			#endif
 			
 		}
 
-		#ifdef DEBUG_1
-			std::cout << "StarDict::StarDict( ) (F)" << "\n";
-			//std::cout << "StarDict::StarDict( ) (D)" << " c = " << c << "\n";
-		#endif
-
 		// FLAGS		// 0x0c
 		dictFile->getChar(&c);
 		FLAGS = (unsigned char)c;
-		
-		#ifdef DEBUG_1
-			std::cout << "StarDict::StarDict( ) (F: if)" << " FLAGS = " << c << "(" << c - '0' << ")" << int(c) << "\n";
-		#endif
-
-		#ifdef DEBUG_1
-			std::cout << "StarDict::StarDict( ) (G)" << "\n";
-		 #endif
 
 		FTEXT    = FLAGS & 1;		// bit 0
 		FHCRC    = FLAGS & 2;		// bit 1
 		FEXTRA   = FLAGS & 4;		// bit 2	ooo
 		FNAME    = FLAGS & 8;		// bit 3
 		FCOMMENT = FLAGS & 16;		// bit 4
-		
-		#ifdef DEBUG_1
-			std::cout << "StarDict::StarDict( ) (H): FTEXT = " << FTEXT << " FHCRC = " << FHCRC <<
-			" FEXTRA = " << FEXTRA << " FNAME = " << FNAME << " FCOMMENT = " << FCOMMENT << "\n";
-		 #endif
-
-		#ifdef DEBUG_1
-			std::cout << "StarDict::StarDict( ) (1)" << "\n";
-		#endif
 
 		dictFile->getChar(&c);
 		MTIME  = (unsigned char)c << 0;
@@ -240,38 +167,17 @@ StarDict::StarDict(const QString &filename, bool wholeStarDict, bool wholeWordsO
 		dictFile->getChar(&c);
 		MTIME |= (unsigned char)c << 24;
 		
-		#ifdef DEBUG_1
-			std::cout << "StarDict::StarDict( ) (2)" << "\n";
-		#endif
-
 		// Compression type
 		// specific compression method		//ooo
 		dictFile->getChar(&c);
 		
-		#ifdef DEBUG_1
-			std::cout << "StarDict::StarDict( ) (2_1): c = " << c << "\n";
-		#endif
-		
 		if ( c == 0x02 ) {
-		
-			#ifdef DEBUG_1
-				std::cout << "StarDict::StarDict( ) (2_2): c = 0x02" << "\n";
-			#endif
-		
 			//return;
 		}
 		
-		#ifdef DEBUG_1
-			std::cout << "StarDict::StarDict( ) (3)" << " COMPRESSION = " << c << "\n";
-		#endif
-		
 		// Operating System
 		dictFile->getChar(&c);
 
-		#ifdef DEBUG_1
-			std::cout << "StarDict::StarDict( ) (4) Operating System = " << c << "\n";
-		#endif
-
 		if ( FEXTRA ) {			//ooo
 			
 			dictFile->getChar(&c);
@@ -281,51 +187,23 @@ StarDict::StarDict(const QString &filename, bool wholeStarDict, bool wholeWordsO
 			
 			this->headerLength += XLEN + 2;		//ooo
 
-			#ifdef DEBUG_1
-				std::cout << "StarDict::StarDict( ) (4_1) headerLength += XLEN + 2 = " << headerLength << "\n";
-			#endif
-
 			readExtraField();
 		}
 
-		#ifdef DEBUG_1
-			std::cout << "\nStarDict::StarDict( ) (5)" << "\n";
-		#endif
-
 		if( FNAME ) {
 			readFileName();
 			
 			this->origFilename = buffer;					//ooo
 			this->headerLength += this->origFilename.length() + 1;		//ooo
-
-			#ifdef DEBUG_1
-				std::cout << "StarDict::StarDict( ) (5_1) headerLength += this->origFilename.length() + 1 = " << headerLength << "\n";
-			#endif
-
-			
 		}
 
-		#ifdef DEBUG_1
-			std::cout << "StarDict::StarDict( ) (6)" << "\n";
-		#endif
-
 		if( FCOMMENT ) {
 			readFileName();
 			
 			comment = buffer;			//ooo
 			headerLength += comment.length()+1;	//ooo
-
-			#ifdef DEBUG_1
-				std::cout << "StarDict::StarDict( ) (6_1) headerLength += comment.length()+1 = " << headerLength << "\n";
-			#endif
-
-			
 		}
 
-		#ifdef DEBUG_1
-			std::cout << "StarDict::StarDict( ) (7)" << "\n";
-		#endif
-
 		if( FHCRC ) {
 			
 			dictFile->getChar(&c);
@@ -334,21 +212,11 @@ StarDict::StarDict(const QString &filename, bool wholeStarDict, bool wholeWordsO
 			*crc16[1] = (unsigned char)c;
 			
 			this->headerLength += 2;	//ooo
-
-			#ifdef DEBUG_1
-				std::cout << "StarDict::StarDict( ) (7_1) headerLength += 2 = " << headerLength << "\n";
-			#endif
-
 		}
 
 		offset = dictFile->pos();
 		//offsetAdditional = offset;	//ooo
 		
-		#ifdef DEBUG_1
-			std::cout << "StarDict::StarDict( ) (End): offset = " << offset << "\n";
-			std::cout << "StarDict::StarDict( ) (End): headerLength = " << headerLength << "\n";
-		#endif
-		
 		offsetAdditional = this->headerLength + 1;	//ooo
 		
 		for ( int i = 0; i < this->CHCNT; i++) {
@@ -380,17 +248,9 @@ void StarDict::readExtraField()
 	dictFile->getChar(&c);
 	SI1 = /*(unsigned char)*/c;
 
-	#ifdef DEBUG_1
-		std::cout << "StarDict::readExtraField() (a): SI1 = " << c << "\n";
-	#endif
-
 	dictFile->getChar(&c);
 	SI2 = /*(unsigned char)*/c;
 		
-	#ifdef DEBUG_1
-		std::cout << "StarDict::readExtraField() (b): SI2 = " << c << "\n";
-	#endif
-
 	// length of the subfield data
 	// length of the subfield data, excluding the 4 initial bytes		//ooo
 
@@ -405,42 +265,23 @@ void StarDict::readExtraField()
 	//int size = (int)LEN - 6;
 	int size = (int)LEN + 4;	//ooo
 	
-	#ifdef DEBUG_1
-		std::cout << "StarDict::readExtraField() (c): LEN = " << LEN << " size = " << size << "\n";
-	#endif
-	
 	// Version
-
 	dictFile->getChar(&c);
 	VER = (unsigned char)c << 0;
 	dictFile->getChar(&c);
 	VER |= (unsigned char)c << 8;
 	
-	#ifdef DEBUG_1
-		std::cout << "StarDict::readExtraField() (d): VER = " << VER << "\n";
-	#endif
-
 	// length of a "chunk" of data
-
 	dictFile->getChar(&c);
 	CHLEN = (unsigned char)c << 0;
 	dictFile->getChar(&c);
 	CHLEN |= (unsigned char)c << 8;
 	
-	#ifdef DEBUG_1
-		std::cout << "StarDict::readExtraField() (e): CHLEN = " << CHLEN << "\n";
-	#endif
-
 	// how many chunks are preset
-
 	dictFile->getChar(&c);
 	CHCNT = (unsigned char)c << 0;
 	dictFile->getChar(&c);
 	CHCNT |= (unsigned char)c << 8;
-	
-	#ifdef DEBUG_1
-		std::cout << "StarDict::readExtraField() (f): CHCNT = " << CHCNT << "\n";
-	#endif
 
 	unsigned long data;
 	//uint data;	//ooo
@@ -454,11 +295,6 @@ void StarDict::readExtraField()
 		dictFile->getChar(&c);
 		data |= (unsigned char)c << 8;
 		
-		#ifdef DEBUG_1a
-			//std::cout << " data[a=" << a << "]="  << data;
-			std::cout << " offsets[a=" << a << "]="  << data;
-		 #endif
-		
 		offsets.append( data );
 	}
 	
@@ -469,11 +305,7 @@ void StarDict::readExtraField()
 
 void StarDict::readFileName()
 {
-  
-	#ifdef DEBUG_1
-		std::cout << "StarDict::readFileName() (1)" << "\n";
-	#endif
- 
+
 	QString filename_str;
 	//char byte;
 	//char *byte;	//ooo
@@ -504,20 +336,12 @@ void StarDict::readFileName()
 	//m_filename = filename_str;
 	m_filename = buffer;	//ooo
 	
-	#ifdef DEBUG_1
-		std::cout << "m_filename = " << m_filename.toAscii().data() << "\n";
-	#endif
-	
 }
 
 
 QString StarDict::search( const QString &word )
 {
 
-	#ifdef DEBUG_1
-		std::cout << "word = " << word.toAscii().data() << "\n";
-	#endif
-
 	struct entry entry;
 	//struct entries entries;			//ooo
 
@@ -537,10 +361,6 @@ QString StarDict::search( const QString &word )
 
 	if (!idxFile->open(QIODevice::ReadOnly )) {
 
-		#ifdef DEBUG_1
-			std::cout << "error *.idx " << "\n";
-		#endif
-
 	}
 
 	QString text;		//ooo
@@ -551,47 +371,21 @@ QString StarDict::search( const QString &word )
 
 	//idxFile->seek(4);
 
-	#ifdef DEBUG_1
-		std::cout << "while (!idxFile->atEnd())" << "\n";
-	#endif
-
 	while( !idxFile->atEnd() ) {
 
 		a = 0;
 		bool finished = false;	//ooo
 
-		#ifdef DEBUG_2
-			std::cout << ".";
-			//std::cout << "line[" << a << " - 1] = " << line[a-1].data() << "\n";
-		#endif
-
 		do {
 
-			#ifdef DEBUG_2
-				std::cout << "do " /*<< "\n"*/;
-			#endif
-
 			idxFile->getChar(&c);
 			line[a] = (unsigned char)c;
 
-			#ifdef DEBUG_2
-				std::cout << "line[" << a << "]= " << line[a] << " ";
-			#endif
-
 			a++;
 
 		} while ( line[a-1] != '\0' );
 
-		#ifdef DEBUG_2
-			std::cout << "while (!idxFile->atEnd()) (B)" << "\n";
-			//std::cout << "line[" << a << " - 1] = " << line[a-1].data() << "\n";
-		#endif
-
-		headword = QString::fromUtf8( line.data() );
-
-		#ifdef DEBUG_2a
-			std::cout << "headword = " << line.data() /*<< "\n"*/;
-		#endif
+		headword = QString::fromUtf8(line.data());
 
 		for( a = 0; a < 8; a++ ) {
 
@@ -600,10 +394,6 @@ QString StarDict::search( const QString &word )
 
 		}
 		
-		#ifdef DEBUG_2a
-			std::cout << "***" << "\n";
-		#endif
-		
 		/*QString word2;
 		word2 = "<p i=01>" + word;
 		
@@ -614,10 +404,6 @@ QString StarDict::search( const QString &word )
 		QRegExp rx( "<(p|p\\si=\\d*)>('?-?\\w*-?'?\\w*|\\W*)" );
 		
 		if ( (pos = rx.indexIn(headword, pos)) != -1 ) {	//ooo
-		
-			#ifdef DEBUG_2a
-				qDebug() << "rx.cap(0) = " << rx.cap(0);
-			#endif
 			
 			if ( QString::compare( rx.cap(2), word, Qt::CaseInsensitive) == 0 ) {
 		  
@@ -654,20 +440,12 @@ QString StarDict::search( const QString &word )
 		}
 			
 		if (!b_wholeStarDict) {
-		  
-			#ifdef DEBUG_1b
-				std::cout << "if (!b_wholeStarDict) { " << "\n"; 
-			#endif
 			
 			if (QString::compare(headword, word, Qt::CaseInsensitive) != 0 
 			&& (indexOfWord < 0 || (indexOfWord > 0 && headword.at(indexOfWord-1) != '>')) ) continue;
 			
 		} else {
 		  
-			#ifdef DEBUG_1b
-				std::cout << "if (!b_wholeStarDict) { (else) " << "\n"; 
-			#endif  
-		  
 		  	if (b_wholeWordsOnly) {
 				if (!foundWholeWord) continue;
 					foundWholeWord = false;
@@ -680,10 +458,6 @@ QString StarDict::search( const QString &word )
 				if (index > 0) {
 					QChar ch = headword.at(index-1);
 					
-					#ifdef DEBUG_1c
-						std::cout << "index = " << index << "\n"; 
-					#endif  
-					
 					//if (ch != ' ' && ch != '<' && ch != '-') continue;
 					if (ch != QChar(0x20) && ch != QChar(0x3E) && ch != QChar(0x2D)) continue;
 				}
@@ -708,18 +482,14 @@ QString StarDict::search( const QString &word )
 		// Catch the size of definition in definition file
 		entry.size = (unsigned char)line[7] + 256 * (unsigned char)line[6] + 256 * 256 * (unsigned char)line[5] + 256 * 256 * 256 *(unsigned char)line[4];
 
-		#ifdef DEBUG_2a
-			std::cout << "\nentry.position = " << entry.position /*<< "\n"*/;
-			std::cout << " entry.size = " << entry.size << "\n";
-		#endif
-
 		// Word found. Break the loop.
 		//break;
 		
 		if (!b_wholeStarDict) {	//ooo
 			break;
 		} else {
-			headwords.append(headword);
+			//headwords.append(headword);
+			headwords.append(headword.toUtf8());
 			positions.append(entry.position);
 			sizes.append(entry.size);
 			continue;
@@ -759,14 +529,6 @@ QString StarDict::search( const QString &word )
 				uint lastChunk = (positions.at(i) + sizes.at(i)) / CHLEN;		//ooo
 				uint lastPos = (positions.at(i) + sizes.at(i)) % CHLEN;			//ooo
 			
-				#ifdef DEBUG_1b
-					std::cout << "headwords.at(i=" << i << ") = " << headwords.at(i).toAscii().data() << "\n"; 
-					std::cout << "chunk " << "(entry.position = " << entry.position << " / " << "CHLEN = " << CHLEN << ") = " << chunk << "\n";
-					std::cout << "pos " << "(entry.position = " << entry.position << " % " << "CHLEN = " << CHLEN << ") = " << pos << "\n";
-					std::cout << "lastChunk = " << lastChunk << "\n";
-					std::cout << "lastPos = " << lastPos << "\n";
-				#endif
-			
 				//QByteArray result;
 				//result.clear();		//ooo
 				result.append("<p><l>"+headwords.at(i).toAscii()+"</l></p>");
@@ -819,13 +581,6 @@ QString StarDict::search( const QString &word )
 		uint lastChunk = (entry.position + entry.size) / CHLEN;		//ooo
 		// Calculate the last position of definition in chunk
 		uint lastPos = (entry.position + entry.size) % CHLEN;		//ooo
-		
-		#ifdef DEBUG_1
-			std::cout << "chunk " << "(entry.position = " << entry.position << " / " << "CHLEN = " << CHLEN << ") = " << chunk << "\n";
-			std::cout << "pos " << "(entry.position = " << entry.position << " % " << "CHLEN = " << CHLEN << ") = " << pos << "\n";
-			std::cout << "lastChunk = " << lastChunk << "\n";
-			std::cout << "lastPos = " << lastPos << "\n";
-		#endif
 
 		// Stores the decompressed data
 		//QByteArray result;
@@ -833,29 +588,14 @@ QString StarDict::search( const QString &word )
 
 		// Definition file
 		dictFile->open( QIODevice::ReadOnly );
-		
-		#ifdef DEBUG_1
-			std::cout << "offsetsWithHeader[chunk = " << chunk << "] = " << offsetsWithHeader[chunk] << "\n";
-			std::cout << "offsetsWithHeader[chunk + 1= " << chunk+1 << "] = " << offsetsWithHeader[chunk+1] << "\n";
-			std::cout << "offsets[chunk = " << chunk << "] = " << offsets[chunk] << "\n";
-		#endif
 
 		// Decompress the data
 		for(uint i = chunk; i <= lastChunk; i++) {	//ooo
-		  
-			#ifdef DEBUG_1
-				std::cout << "\n**** i = " << i << "****" << "\n";
-			#endif
 		 
 			// Jump to chunk we are looking for
 			dictFile->seek( offsetsWithHeader[i] );
 			unsigned int chunkLen = offsets[i];
 
-			#ifdef DEBUG_1
-				std::cout << "offsets[chunk=" << chunk << "]=" << offsets[chunk] << "\n";
-				std::cout << "chunkLen = " << chunkLen << "\n";
-			#endif
-
 			unsigned char data[chunkLen];		//ooo
 
 			// Get the compressed data
@@ -864,26 +604,13 @@ QString StarDict::search( const QString &word )
 				data[a] = (unsigned char)c;
 			}
 			
-			#ifdef DEBUG_1
-				std::cout << "*** *** pt = " << pt << "\n";
-				//std::cout << "\n*** *** data = " << data << "\n\n";
-			#endif
-			
 			if( i == chunk && i == lastChunk) {
-			  
-				#ifdef DEBUG_1
-					std::cout << "***> if( i == chunk && i == lastChunk)" << "\n";
-				#endif
-			 
+
 				memcpy(pt, Inflate(data, offsets[i]) + pos, lastPos - pos);
 				pt[lastPos-pos] = '\0';						//ooo
 			  
 			} else {
-			  
-				#ifdef DEBUG_1
-					std::cout << "****> if( i == chunk && i == lastChunk): (else)" << "\n";
-				#endif
-			
+
 				if( i == chunk ) {
 			
 					memcpy(pt, Inflate(data, offsets[i]) + pos, CHLEN - pos);
@@ -902,16 +629,12 @@ QString StarDict::search( const QString &word )
 				}
 			}
 			
-			#ifdef DEBUG_1
-				std::cout << "\n*** *** *** pt = " << pt << "\n";
-			#endif
-			
 			//result.append( Inflate( data4, offsets[i] ));
 			//result.append( parseData(pt).toAscii().data() );			//ooo
 			result.append(pt);
 
 		}
-		}
+		}	//else
 		dictFile->close();
 		
 		// Returns only the definition
@@ -919,38 +642,19 @@ QString StarDict::search( const QString &word )
 
 	} else {
 
-		#ifdef DEBUG_1
-			std::cout << "isCompressed = false (1)" << "\n";
-			//std::cout << "pos = " << pos << "\n";
-		#endif
-
 		// The file is not compressed
 		if (!dictFile->open(QIODevice::ReadOnly)) {
 
-			#ifdef DEBUG_1
-				std::cout << "error *.idx " << "\n";
-			#endif
-
 		}
 
 		// Jump to position of definition
 		dictFile->seek(entry.position);
 
-		#ifdef DEBUG_1
-			std::cout << "isCompressed = false (2)" << "\n";
-			//std::cout << "pos = " << pos << "\n";
-		#endif
-
 		// Get the definition
 		QByteArray result;
 		result.clear();		//ooo
 		result.resize( entry.size + 1 );
 
-		#ifdef DEBUG_1
-			std::cout << "isCompressed = false (3)" << "\n";
-			std::cout << "entry.size = " << entry.size << "\n";
-		#endif
-
 		for( uint a = 0; a < entry.size; a++ ) {
 
 			dictFile->getChar(&c);
@@ -963,12 +667,6 @@ QString StarDict::search( const QString &word )
 		dictFile->close();
 
 		// Return the result
-
-		#ifdef DEBUG_3
-			std::cout << "result.data() = " << result.data() << "\n";
-			//std::cout << "pos = " << pos << "\n";
-		#endif
-
 		return QString::fromUtf8( result.data() );
 	}
 }
@@ -977,14 +675,6 @@ QString StarDict::search( const QString &word )
 char* StarDict::Inflate( unsigned char *data, unsigned long size )		//ooo
 {
 	
-	#ifdef DEBUG_1
-		std::cout << "\nInflate()" << "\n";
-		std::cout << "CHUNK = " << CHUNK << "\n";
-		std::cout << "size = " << size << "\n";
-		//std::cout << "data.size() = " << data.size() << "\n";
-	#endif
-
-	
 	int ret;
 	unsigned have;			//ooo
 	//int have;			//ooo
@@ -1013,13 +703,6 @@ char* StarDict::Inflate( unsigned char *data, unsigned long size )		//ooo
 		// Compressed data
 		strm.avail_in = size;			//ooo
 		strm.next_in = (Bytef*)data;		//ooo
-
-		#ifdef DEBUG_1
-			//std::cout << "data.size() = " << data.size() << "\n";
-			//std::cout << "str2.size() = " << str2.size() << "\n";
-			//std::cout << "size = " << size << "\n";
-			//std::cout << "data2.data() = " << data2.data() << "\n";
-		 #endif
 	
 		/* run inflate() on input until output buffer not full */
 		do {
@@ -1030,74 +713,31 @@ char* StarDict::Inflate( unsigned char *data, unsigned long size )		//ooo
 			ret = inflate(&strm, Z_PARTIAL_FLUSH);	//ooo
 			//assert(ret != Z_STREAM_ERROR);  /* state not clobbered */	//ooo
 
-			#ifdef DEBUG_1
-				std::cout << "\nret = " << ret << "\n";
-			#endif
-
 			if ( ret != Z_OK ) {
 
-				#ifdef DEBUG_1
-					std::cout << "ret != Z_OK\n";
-				#endif
-
 			}
-
-			#ifdef DEBUG_1
-				std::cout << "\nZ_NEED_DICT (1) = " << Z_NEED_DICT << "\n";
-				std::cout << "Z_STREAM_ERROR (2) = " << Z_STREAM_ERROR << "\n";
-				std::cout << "Z_DATA_ERROR (3) = " << Z_DATA_ERROR << "\n";
-				std::cout << "Z_MEM_ERROR (4) = " << Z_MEM_ERROR << "\n\n";
-			#endif
 		
 			switch (ret) {
 				case Z_NEED_DICT:
 					ret = Z_DATA_ERROR;     /* and fall through */
 					
-					#ifdef DEBUG_1
-						std::cout << "-->	Z_NEED_DICT (1)" << "\n";
-					#endif
-
 				case Z_STREAM_ERROR:
-				  
-					#ifdef DEBUG_1
-						std::cout << "-->	Z_STREAM_ERROR (2)" << "\n";
-					#endif
-
 					break;
 					
 				case Z_DATA_ERROR:
-				  
-					#ifdef DEBUG_1
-						std::cout << "-->	Z_DATA_ERROR (3)" << "\n";
-					#endif
-
 					break;
 				  
 				case Z_MEM_ERROR:
 					(void)inflateEnd(&strm);
-					
-					#ifdef DEBUG_1
-						std::cout << "-->	Z_MEM_ERROR (4)" << "\n";
-					#endif
-
 					break;
 			}
 			
 			have = CHUNK - strm.avail_out;		//ooo
 			
-			#ifdef DEBUG_1
-				std::cout << "have = " << have << "(CHUNK = " << CHUNK << " - " << "strm.avail_out = " << strm.avail_out << ")" << "\n";
-			#endif
-			
 			/*if (fwrite(out, 1, have, dest) != have || ferror(dest)) {	//ooo
 				(void)inflateEnd(&strm);
 				return Z_ERRNO;
 			}*/
-			
-			#ifdef DEBUG_1
-				//std::cout << "pt = " << pt << "\n";
-				//std::cout << "out = " << out << "\n";
-			#endif
 
 		} while (strm.avail_out == 0);
 		
@@ -1110,11 +750,6 @@ char* StarDict::Inflate( unsigned char *data, unsigned long size )		//ooo
 	//return result;
 	
 	//std::cout << "StarDict::parseData = " << parseData(out).toAscii().data() << "\n";	//ooo
-	
-	#ifdef DEBUG_1
-		std::cout << "out = " << out << "\n";
-		std::cout << "\nStarDict::Inflate() (End) *****************************" << "\n\n";
-	#endif
 
 	return &out[0];			//ooo
 }
@@ -1122,7 +757,8 @@ char* StarDict::Inflate( unsigned char *data, unsigned long size )		//ooo
 
 QString StarDict::parseData(const char *data)
 {
-
+	//return QString();	//ooo
+	return "Not implemented";
 }
 
 
