@@ -3,8 +3,8 @@
 
                              -------------------
     begin                : 27. November 2009
-    copyright            : (c) 2007 by Roland Suchan
-    email                : vmp@arcor.de
+    copyright            : (c) 2007 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
     license              : GPL v 2.0
  ***************************************************************************/
 
@@ -61,7 +61,7 @@ public:
 	QString filename() const { return m_filename; };
 	QString search( const QString & );
 	char* Inflate( unsigned char *data, unsigned long size);	//ooo
-	QString parseData(const char *data);			//ooo
+	QString parseData(const char *data);				//ooo
 	//FILE *f;
 	QFile *f;
 	int wordcount;
@@ -107,7 +107,7 @@ protected:
 	unsigned long offsetAdditional;		//ooo
 
 	char c;
-	int type;	//ooo
+	int type;			//ooo
 	char buffer[BUFFERSIZE];	//ooo
 	char *byte;			//ooo
 
