@@ -2,8 +2,8 @@
                           settings.cpp  -  description
                              -------------------
     begin                : December 2007
-    copyright            : (c) 2007 by Roland Suchan
-    email                : vmp@arcor.de
+    copyright            : (c) 2007 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
     license              : GPL v 2.0
  ***************************************************************************/
 
@@ -33,6 +33,8 @@
 #include <KWindowSystem>
 #include <KShortcut>
 #include <KMessageBox>
+#include <QGridLayout>		//ooo
+#include <KDebug>
 
 #include "settings.h"
 #include "settings_widg.h"
@@ -123,6 +125,8 @@ Settings::Settings(QTrans *parent)
 	page2->setIcon( KIcon( /*"misc"*/"applications-accessories" ) );
 
 	addPage( page2 );
+	
+	QGroupBox *groupBox = new QGroupBox(tr(""/*"&Push Buttons"*/));
 
 	QVBoxLayout *miscLayout = new QVBoxLayout(label);
 
@@ -144,9 +148,9 @@ Settings::Settings(QTrans *parent)
 	mouseSelection = new QCheckBox( "mouseSelection", label );	//ooo
 	mouseSelection->setText(i18n("Translate mouse selection"));
 
-	StatusBar = new QCheckBox( "StatusBar", label );	//ooo
+	StatusBar = new QCheckBox( "StatusBar", label );		//ooo
 	StatusBar->setText(i18n("Enable Status Bar"));
-
+	
 	miscLayout->addWidget(AutoPop);
 	miscLayout->addWidget(DontClose);
 	miscLayout->addWidget(DockIcon);
@@ -162,7 +166,7 @@ Settings::Settings(QTrans *parent)
 	miscLayout->addLayout(h2Layout);
 
 	miscLayout->addWidget(mouseSelection);
-	miscLayout->addWidget(StatusBar);			//ooo
+	miscLayout->addWidget(StatusBar);				//ooo
 
 	//TextLabel3 = new QLabel("TextLabel3", label );
 	TextLabel3 = new QLabel("TextLabel3");
@@ -179,17 +183,82 @@ Settings::Settings(QTrans *parent)
 	h3Layout->addWidget(Charset);
 	//miscLayout->addLayout(h3Layout);
 
-	TextLabel5 = new QLabel("TextLabel5", label );	//ooo
+	TextLabel5 = new QLabel("TextLabel5", label );			//ooo
 	TextLabel5->setText(i18n("Widget Style :"));
 	widgetStyle = new KComboBox(false, label);
 	for (int j=0;StyleName[j]!=0L;j++) {
 		widgetStyle->addItem(StyleName[j],j);
 	}
 
-	QHBoxLayout *h5Layout = new QHBoxLayout(label);	//ooo
+	QHBoxLayout *h5Layout = new QHBoxLayout(label);			//ooo
 	h5Layout->addWidget(TextLabel5);
 	h5Layout->addWidget(widgetStyle);
 	miscLayout->addLayout(h5Layout);
+	
+	//setLayout(miscLayout);					//ooo
+	groupBox->setLayout(miscLayout);
+	
+	QGroupBox *groupBox2 = new QGroupBox(tr(""/*"Exclusive Radio Buttons"*/));
+	
+	//QRadioButton *radio1 = new QRadioButton(tr("&Radio button 1"));
+	//QRadioButton *radio2 = new QRadioButton(tr("R&adio button 2"));
+	//QRadioButton *radio3 = new QRadioButton(tr("Ra&dio button 3"));
+
+	//radio1->setChecked(true);
+	
+	EnableRecordingOfWordTranslation = new QCheckBox("StartMin");
+	EnableRecordingOfWordTranslation->setText(i18n("Record Translation"));
+	
+	QHBoxLayout *hALayout = new QHBoxLayout();
+	//hALayout->addSpacing(40);
+	hALayout->addWidget(EnableRecordingOfWordTranslation);
+	//miscLayout->addLayout(h1Layout);
+	
+	TextLabel6 = new QLabel("TextLabel6");				//ooo
+	TextLabel6->setText(i18n("Number Recordings :"));
+	numberRecodings = new KComboBox(false);
+	for (int j=0; j<100; j++) {
+		numberRecodings->addItem(QString("%1").arg((j+1)*10), j);
+	}
+	
+	QHBoxLayout *hBLayout = new QHBoxLayout();			//ooo
+	hBLayout->addSpacing(40);
+	hBLayout->addWidget(TextLabel6);
+	hBLayout->addWidget(numberRecodings);
+	//miscLayout->addLayout(h5Layout);
+	
+	TextLabel7 = new QLabel("TextLabel7");				//ooo
+	TextLabel7->setText(i18n("Character Map (Font Size) :"));
+	fontSizeCharacterMap = new KComboBox(false);
+	
+	QHBoxLayout *hCLayout = new QHBoxLayout();
+	hCLayout->addWidget(TextLabel7);
+	hCLayout->addWidget(fontSizeCharacterMap);
+	
+	QVBoxLayout *vbox = new QVBoxLayout();
+	//vbox->addWidget(radio1);
+	//vbox->addWidget(radio2);
+	//vbox->addWidget(radio3);
+	vbox->addLayout(hALayout);
+	vbox->addLayout(hBLayout);
+	//vbox->addLayout(hCLayout);
+	vbox->addStretch(1);
+	
+	groupBox2->setLayout(vbox);
+
+	QGridLayout *grid = new QGridLayout(label);
+	//grid->addWidget(createFirstExclusiveGroup(), 0, 0);
+	grid->addWidget(groupBox, 0, 0);
+	//grid->addWidget(createSecondExclusiveGroup(), 1, 0);
+	grid->addWidget(groupBox2, 0, 1);
+	//grid->addWidget(createPushButtonGroup(), 1, 1);
+	//setLayout(grid, label);
+
+	//setWindowTitle(tr("Group Boxes"));
+	//resize(480, 320);
+	
+	//miscLayout->addLayout(grid);					//ooo
+	//miscLayout->addWidget(grid);					//ooo
 
 // ******* ShortCut Panel *******
 	label = new QLabel( /*"Third Test Page"*/ );
@@ -311,7 +380,7 @@ Settings::Settings(QTrans *parent)
 
 	QString strGoToLine = "";
 
-	for (int i = 1; i <= Bab->Data->count(); i++) {	//ooo
+	for (int i = 1; i <= Bab->Data->count(); i++) {		//ooo
 		Bab->cGoToLine->addItem(strGoToLine.setNum(i));
 	}
 
@@ -331,7 +400,8 @@ Settings::Settings(QTrans *parent)
 	//widgetStyle->setItemText(0,parent->widgetStyle);
 	//widgetStyle->setItemText(widgetStyle->findText(parent->widgetStyle),parent->widgetStyle);
 	//widgetStyle->currentIndex(widgetStyle->findText(parent->widgetStyle));
-	widgetStyle->setCurrentIndex(widgetStyle->findText(parent->widgetStyle));	//ooo
+	widgetStyle->setCurrentIndex(widgetStyle->findText(parent->widgetStyle));		//ooo
+	numberRecodings->setCurrentIndex(numberRecodings->findText(parent->numberRecodings));	//ooo
 
 /*	if (parent->widgetStyle != "") {	//ooo
 		QChar c = parent->ShortKey[5];
@@ -361,7 +431,12 @@ Settings::Settings(QTrans *parent)
 		mouseSelection->setChecked(true);
 	if (parent->StatusBarSelected)
 		StatusBar->setChecked(true);
-
+	if (parent->EnableRecording) {
+		EnableRecordingOfWordTranslation->setChecked(true);
+		numberRecodings->setEnabled(true);
+	} else {
+		numberRecodings->setDisabled(true);
+	}
 	if (parent->enableShortCut)
 		EnableShortCut->setChecked(true);
 	if (parent->ShortKey != "") {
@@ -397,8 +472,9 @@ void Settings::slot_Ok()
 
 int Settings::slot_apply()
 {
-	bool hideTask_State = Par->hideTask;   //ooo
-	Par->widgetStyle = widgetStyle->currentText();	//ooo
+	bool hideTask_State = Par->hideTask;   				//ooo
+	Par->widgetStyle = widgetStyle->currentText();			//ooo
+	Par->numberRecodings = numberRecodings->currentText();		//ooo
 
 	Par->English_Path = Bab->eBasePath->text();
 	Par->bab_dict->clear();
@@ -411,6 +487,19 @@ int Settings::slot_apply()
 		Par->bab_dict->append(*it);
 		Par->actionsList.append(Par->languageMenu->addAction(QIcon(QPixmap(Bab->flagPath+Flag[(*it).flagID])), (*it).Language));
 	}
+	
+	if (Bab->Data->count()+1 != Bab->cGoToLine->count()) {
+	  
+		QString strGoToLine = "";
+	  
+		Bab->cGoToLine->clear();
+		Bab->cGoToLine->addItem(i18n("None"), tr(""));
+		for (int i = 1; i <= Bab->Data->count(); ++i) {
+			Bab->cGoToLine->addItem(strGoToLine.setNum(i));
+		}
+		Bab->cGoToLine-> setCurrentIndex(0);
+	}
+	
 
 	Par->fontType = chooseFont->font();
 	//Par->Out->setFont(Par->fontType.family(),Par->fontType.pointSize(),Par->Charset);
@@ -443,6 +532,33 @@ int Settings::slot_apply()
 		Par->StatusBarSelected = false;
 		Par->QMainWindow::statusBar()->hide();
 	}
+	
+	if (EnableRecordingOfWordTranslation->isChecked()) {					//ooo
+		Par->EnableRecording = true;
+		Par->Out->saveOutputAct_->setEnabled(false);					//ooo
+		//Par->Out->saveOutputAct_->setVisible(false);					//ooo
+		numberRecodings->setEnabled(true);
+		if (Par->list.count() >= Par->numberRecodings.toInt()) {
+			QList<QString>::iterator itr;   					//ooo
+			int counter = 0;
+			for ( itr = Par->list.begin(); itr != Par->list.end(); ++itr ) {
+				if ( ( Par->list.count() - counter ) == Par->numberRecodings.toInt() ) {
+					//Par->list.erase(itr,Par->list.end());
+					Par->list.erase(Par->list.begin(),itr);
+					break;
+				}
+				++counter;
+			}
+		}
+	} else {
+		Par->EnableRecording = false;
+		numberRecodings->setDisabled(true);
+		Par->list.clear();								//ooo
+		Par->leftAct->setEnabled(false);						//ooo
+		Par->rightAct->setEnabled(false);						//ooo
+		Par->Out->saveOutputAct_->setEnabled(true);					//ooo
+		//Par->Out->saveOutputAct_->setVisible(true);					//ooo
+	}
 
 	if (DockIcon->isChecked()) {
 		Par->DockIcon = true;
