@@ -2,8 +2,8 @@
                           settings.h  -  description
                              -------------------
     begin                : December 2007
-    copyright            : (c) 2007 by Roland Suchan
-    email                : vmp@arcor.de
+    copyright            : (c) 2007 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
     license              : GPL v 2.0
  ***************************************************************************/
 
@@ -60,21 +60,28 @@ public:
 	QCheckBox* DockIcon;
 	QCheckBox* StartMin;
 	QCheckBox* hideTask;
-	QCheckBox* mouseSelection;	//ooo
-	QCheckBox* StatusBar;		//ooo
+	QCheckBox* mouseSelection;			//ooo
+	QCheckBox* StatusBar;				//ooo
+	
+	QCheckBox* EnableRecordingOfWordTranslation;	//ooo
 
 	QCheckBox* EnableShortCut;
 	KComboBox* Char;
 	KComboBox* Charset;
-	KComboBox* widgetStyle;	//ooo
+	KComboBox* widgetStyle;				//ooo
+	KComboBox* numberRecodings;			//ooo
+	KComboBox* fontSizeCharacterMap;		//ooo
+	
 	QLabel* TextLabel3;
 	QLabel* TextLabel4;
-	QLabel* TextLabel5;	//ooo
+	QLabel* TextLabel5;				//ooo
+	QLabel* TextLabel6;				//ooo
+	QLabel* TextLabel7;				//ooo
 
 	KColorButton *colorBtBack;
 	KColorButton *colorBtText;
-	KColorButton *colorBtExpressionText;	//ooo
-	KColorButton *colorBtSentencePartText;	//ooo
+	KColorButton *colorBtExpressionText;		//ooo
+	KColorButton *colorBtSentencePartText;		//ooo
 
 	QTrans* Par;
 	Settings_widg *Bab;
