@@ -2,8 +2,8 @@
                           settings_widg.cpp  -  description
                              -------------------
     begin                : December 2007
-    copyright            : (c) 2007 by Roland Suchan
-    email                : vmp@arcor.de
+    copyright            : (c) 2007 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
     license              : GPL v 2.0
  ***************************************************************************/
 
@@ -48,11 +48,11 @@
 #include <QPoint>
 
 #include <KDebug>	//ooo
+#include <QColor>	//ooo
 
 #include "settings_widg.h"
 #include "utils.h" //where is defined the FlagsID array
 
-//#define DEBUG_1
 
 //Settings_widg::Settings_widg( QWidget *parent ) :
 Settings_widg::Settings_widg( QWidget *parent, QMouseEvent *event ) :	//ooo
@@ -61,7 +61,7 @@ Settings_widg::Settings_widg( QWidget *parent, QMouseEvent *event ) :	//ooo
 	//Par1 = parent;   //ooo
 	Par_mouseEvent = event;	//ooo
 	prevItem = 0;	//ooo
-	tableItemColor = QColor(0, 0, 255, 64);	//ooo
+	tableItemColor = QColor(0, 0, 255, 64);		//ooo
 
 	Data = new QList<Dictionary>;
 	//Data->setAutoDelete(true);
@@ -148,11 +148,19 @@ Settings_widg::Settings_widg( QWidget *parent, QMouseEvent *event ) :	//ooo
 	//setBaseSize(10000, 200);
 
 	moveOnTopAct = new QAction(KIcon("go-top"/*"arrow-up-double"*/), tr("Move on &Top"), this);
+	moveOnTopAct->setIconVisibleInMenu(true);
 	moveUpAct = new QAction(KIcon("go-up"/*"arrow-up"*/), tr("Move &Up"), this);
+	moveUpAct->setIconVisibleInMenu(true);
 	moveDownAct = new QAction(KIcon("go-down"/*"arrow-down"*/), tr("Move &Down"), this);
+	moveDownAct->setIconVisibleInMenu(true);
 	moveToLineAct = new QAction(KIcon("go-down"/*"arrow-down"*/), tr("Move to Line"), this);
+	moveToLineAct->setIconVisibleInMenu(true);
+	findItemAct = new QAction(KIcon("edit-find-replace"), tr("&Find"), this);
+	findItemAct->setIconVisibleInMenu(true);
 	editAct = new QAction(KIcon("document-properties"), tr("&Edit"), this);
+	editAct->setIconVisibleInMenu(true);
 	removeDictionaryAct = new QAction(KIcon("edit-delete"), tr("&Remove dictionary"), this);
+	removeDictionaryAct->setIconVisibleInMenu(true);
 
 	connect(bAdd,SIGNAL(clicked()),this,SLOT(slot_Add()));
 	connect(bRemoveAll,SIGNAL(clicked()),this,SLOT(slot_RemoveAll()));
@@ -170,6 +178,8 @@ Settings_widg::Settings_widg( QWidget *parent, QMouseEvent *event ) :	//ooo
 	connect(tableWidget,SIGNAL(cellDoubleClicked(int, int)),this,SLOT(slot_tableClicked(int, int)));	//ooo
 
 	//connect(tableWidget,SIGNAL(cellClicked(int, int)),SLOT(slot_showMenu(int, int)));
+	
+	connect(findItemAct,SIGNAL(triggered()), SLOT(slot_findItem()));
 
 	connect(editAct,SIGNAL(triggered()), SLOT(slot_editRow()));
 
@@ -356,6 +366,7 @@ void Settings_widg::slot_tableClicked(int row, int column)
 	setupDictionaryMenu->addAction(moveUpAct);
 	setupDictionaryMenu->addAction(moveDownAct);
 	setupDictionaryMenu->addSeparator();
+	setupDictionaryMenu->addAction(findItemAct);
 	setupDictionaryMenu->addAction(editAct);
 	setupDictionaryMenu->addAction(removeDictionaryAct);
 	if (selectedRow == 0) {
@@ -479,12 +490,6 @@ void Settings_widg::slot_moveToLine()
 */
 	//Data->move(selectedRow, selectedRow-1);
 
-#ifdef DEBUG_1
-	qDebug() << "selectedRow = " << selectedRow;
-	qDebug() << "cGoToLine->currentIndex() = " << cGoToLine->currentIndex();
-#endif
-
-
 	if (cGoToLine->currentIndex() != 0 && selectedRow != cGoToLine->currentIndex()-1) {
 		Data->move(selectedRow,cGoToLine->currentIndex()-1);
 		repaintTable();
@@ -540,6 +545,63 @@ void Settings_widg::slot_moveOnTop()
 }
 
 
+void Settings_widg::slot_findItem()
+{
+	/*KMessageBox::sorry(this,
+		i18n("<qt>You have to <u>insert</u> something!</qt>"));*/
+		
+
+	FindTableWidget *widgetFind = new FindTableWidget(this);
+	widgetFind->show();
+		
+	/*if (tableWidget) {
+		QString item = "BGL";	// Decode MIME data here.
+		Qt::MatchFlag someFlag = Qt::MatchContains;	// Check documentation for match type.
+		QList<QTableWidgetItem *> items = tableWidget->findItems(item, someFlag);
+		//int firstRow = tableWidget->row(items[0]);
+		//int secondRow = tableWidget->row(items[1]);
+		//int thirdRow = tableWidget->row(items[2]);
+		//int lastRow = tableWidget->row(items[items.size()-1]);
+		QTableWidgetItem *horizontalItem;
+		
+		//QMessageBox::about(this, i18n("Item found at"), QString("firstRow = %1").arg(firstRow));
+		//QMessageBox::about(this, i18n("Item found at"), QString("secondRow = %1").arg(secondRow));
+		//QMessageBox::about(this, i18n("Item found at"), QString("thirdRow = %1").arg(thirdRow));
+		//QMessageBox::about(this, i18n("Item found at"), QString("lastRow = %1").arg(lastRow));
+		//QMessageBox::about(this, i18n("Item found at"), QString("items.size() = %1").arg(items.size()));
+		
+		//for ( int i=0; i<items.size(); ++i) {
+		//	QMessageBox::about(this, i18n("Item found at"), QString("%1 : row = %2, column = %3").arg(i).arg(tableWidget->row(items[i])).arg(tableWidget->column(items[i])));
+		//}
+		
+		//QMessageBox::about(this, i18n("Item found at"), QString("items.size() = %1").arg(items.size()));
+		
+		
+		for (int row = tableWidget->row(items[0]); row < items.size(); row = tableWidget->row(items[++i])) {
+			//tableWidget->row(i);
+			//Qt::SortOrder order = Qt::AscendingOrder;
+			//tableWidget->sortItems ( column, order);
+			//horizontalHeaderItem = tableWidget->horizontalHeaderItem(column);
+			horizontalItem = tableWidget->item(0, row);
+			horizontalItem->setBackground(tableItemColor);
+			//++i;
+			//row = tableWidget->row(items[i]);
+		}
+		
+		for (int j=0; j < items.size(); ++j) {
+			//tableWidget->row(i);
+			//Qt::SortOrder order = Qt::AscendingOrder;
+			//tableWidget->sortItems ( column, order);
+			//horizontalHeaderItem = tableWidget->horizontalHeaderItem(column);
+			horizontalItem = tableWidget->item(tableWidget->row(items[j]), tableWidget->column(items[j]));
+			horizontalItem->setBackground(tableItemColor);
+			//++i;
+			//row = tableWidget->row(items[i]);
+		}
+	}*/
+  
+}
+
 void Settings_widg::slot_editRow(/*int row*/)
 {
 	Dictionary Item = Data->at(selectedRow);
@@ -577,15 +639,15 @@ void Settings_widg::repaintTable()
         	codecItem->setFlags(Qt::ItemIsEnabled);
 		codecItem->setTextAlignment(Qt::AlignCenter);
 
-		QTableWidgetItem *directionItem = new QTableWidgetItem(right_to_left_Direction[(*itr).directionID]);	//ooo
+		QTableWidgetItem *directionItem = new QTableWidgetItem(right_to_left_Direction[(*itr).directionID]);		//ooo
         	directionItem->setFlags(Qt::ItemIsEnabled);
 		directionItem->setTextAlignment(Qt::AlignCenter);
 
-		QTableWidgetItem *disableItem = new QTableWidgetItem(disable_enable[(*itr).disableID]);			//ooo
+		QTableWidgetItem *disableItem = new QTableWidgetItem(disable_enable[(*itr).disableID]);				//ooo
         	disableItem->setFlags(Qt::ItemIsEnabled);
 		disableItem->setTextAlignment(Qt::AlignCenter);
 
-		//QTableWidgetItem *encodingItem = new QTableWidgetItem(encoding[(*itr).encodingID]);			//ooo
+		//QTableWidgetItem *encodingItem = new QTableWidgetItem(encoding[(*itr).encodingID]);				//ooo
 		QTableWidgetItem *encodingItem = new QTableWidgetItem(Codec[(*itr).encodingExpressionID]);			//ooo
         	encodingItem->setFlags(Qt::ItemIsEnabled);
 		encodingItem->setTextAlignment(Qt::AlignCenter);
@@ -668,9 +730,10 @@ void Settings_widg::addDictionary(QString fileName, QString language, int flagID
 	//Dictionary *Item = new Dictionary(fileName,language,flagID,codecID,directionID,disableID,encodingID);	//ooo
 	Dictionary *Item = new Dictionary(fileName,language,flagID,encodingDefinitionID,directionID,disableID,encodingExpressionID);	//ooo
 	Data->append(*Item);
-	if (!bRemoveAll->isEnabled())
+	if (!bRemoveAll->isEnabled()) {
 		bRemoveAll->setEnabled(true);
-
+	}
+	
 }
 
 
@@ -988,6 +1051,7 @@ void CAddWidget::slot_OpenFile()
 				"*.bgl | Babylon Dictionaries (*.bgl)\n"
 				"*.dic.txt | Plain Text Dictionaries (*.dic.txt)\n"
 				"*.ifo | StarDict Dictionaries (*.ifo)\n"
+				"*.index | Dictd Dictionaries (*.index)\n"
 				"* | All files (*.*)"));
 	if (fileName != QString::null)
 		eFileName->setText(fileName);
@@ -1027,4 +1091,160 @@ void Table_widg::mousePressEvent(QMouseEvent *event)
 
 }
 
+
+FindTableWidget::FindTableWidget(Settings_widg *parent) : QWidget(parent, Qt::Dialog)
+{
+	Par2 = parent;
+	
+	tableItemColor = QColor(191, 217, 255, 255);		//ooo
+
+	setWindowModality(Qt::WindowModal);
+	setWindowTitle(i18n("Find Text"));
+
+	setMinimumSize(300, 190);
+	resize(240, 220);
+
+	mainLayout = new QVBoxLayout(this);
+	Box1 = new QHBoxLayout(this);
+	Label1 = new QLabel(i18n("Text to find:"),this);
+	wordName = new QLineEdit(this);
+
+	Box1->setSpacing(5);
+	Box1->addWidget(Label1);
+	Box1->addWidget(wordName);
+	
+	bRadio  = new QRadioButton("Contains", this);
+	bRadio->setChecked(true);
+	bRadio1 = new QRadioButton("Case Sensitive", this);
+	bRadio2 = new QRadioButton("Starts With", this);
+	bRadio3 = new QRadioButton("Ends With", this);
+	bRadio4 = new QRadioButton("Wildcard", this);
+
+	Box4 = new QHBoxLayout(this);
+	bOk = new QPushButton(i18n("&OK"),this);
+	bOk->setDefault(true);
+	bCancel = new QPushButton(i18n("&Cancel"),this);
+	Box4->setSpacing(5);
+	Box4->addStretch();
+	Box4->addWidget(bOk);
+	Box4->addWidget(bCancel);
+
+	//wordName->setText(Par2->selectedText());
+
+	//mainLayout->addLayout(Box1);
+	mainLayout->addWidget(Label1);
+	//mainLayout->setSpacing(1);
+	mainLayout->addWidget(wordName);
+	mainLayout->addWidget(bRadio);
+	mainLayout->addWidget(bRadio1);
+	mainLayout->addWidget(bRadio2);
+	mainLayout->addWidget(bRadio3);
+	mainLayout->addWidget(bRadio4);
+	mainLayout->addLayout(Box4);
+
+	connect(bCancel,SIGNAL(clicked()),this,SLOT(slot_Close()));
+	connect(bOk,SIGNAL(clicked()),this,SLOT(slot_Ok()));
+
+}
+
+
+FindTableWidget::~FindTableWidget()
+{
+}
+
+
+void FindTableWidget::slot_Close()
+{
+	close();
+}
+
+
+void FindTableWidget::slot_Ok()
+{
+	//Par2->findText(wordName->text());
+	
+	if (Par2->tableWidget) {
+	  
+		if (wordName->text() != "") {
+		  
+			QTableWidgetItem *tableItem;
+		
+			//QMessageBox::about(this, i18n("Item found at"), QString("columnCount() = %1, rowCount()= %2").arg(Par2->tableWidget->columnCount()).arg(Par2->tableWidget->rowCount()));
+		
+			for ( int i=0; i < Par2->tableWidget->columnCount(); ++i ) {
+				for ( int j=0; j < Par2->tableWidget->rowCount(); ++j ) {
+					tableItem = Par2->tableWidget->item(j, i);
+					if ( tableItem->background() != Qt::white ) {
+						//tableItem->setBackground(QColor(255, 255, 255, 255));
+						tableItem->setBackground(Qt::white);
+					}
+				}
+			}
+			
+			Qt::MatchFlag someFlag;
+	  
+			//QString item = "BGL";
+			
+			if ( bRadio->isChecked() ) {			// Check dictionary table for match type.
+				someFlag = Qt::MatchContains;
+			} else if ( bRadio1->isChecked() ) {
+				someFlag = Qt::MatchCaseSensitive;
+			} else if ( bRadio2->isChecked() ) {
+				someFlag = Qt::MatchStartsWith;
+			} else if ( bRadio3->isChecked() ) {
+				someFlag = Qt::MatchEndsWith;
+			} else if ( bRadio4->isChecked() ) {
+				someFlag = Qt::MatchWildcard;
+			}
+			
+			QList<QTableWidgetItem *> items = Par2->tableWidget->findItems(wordName->text()/*item*/, someFlag);
+			/*int firstRow = tableWidget->row(items[0]);
+			int secondRow = tableWidget->row(items[1]);
+			int thirdRow = tableWidget->row(items[2]);
+			int lastRow = tableWidget->row(items[items.size()-1]);*/
+
+		
+			/*QMessageBox::about(this, i18n("Item found at"), QString("firstRow = %1").arg(firstRow));
+			QMessageBox::about(this, i18n("Item found at"), QString("secondRow = %1").arg(secondRow));
+			QMessageBox::about(this, i18n("Item found at"), QString("thirdRow = %1").arg(thirdRow));
+			QMessageBox::about(this, i18n("Item found at"), QString("lastRow = %1").arg(lastRow));*/
+			//QMessageBox::about(this, i18n("Item found at"), QString("items.size() = %1").arg(items.size()));
+		
+			/*for ( int i=0; i<items.size(); ++i) {
+				QMessageBox::about(this, i18n("Item found at"), QString("%1 : row = %2, column = %3").arg(i).arg(tableWidget->row(items[i])).arg(tableWidget->column(items[i])));
+			}
+		
+			QMessageBox::about(this, i18n("Item found at"), QString("items.size() = %1").arg(items.size()));*/
+		
+		
+			/*for (int row = tableWidget->row(items[0]); row < items.size(); row = tableWidget->row(items[++i])) {
+				//tableWidget->row(i);
+				//Qt::SortOrder order = Qt::AscendingOrder;
+				//tableWidget->sortItems ( column, order);
+				//horizontalHeaderItem = tableWidget->horizontalHeaderItem(column);
+				horizontalItem = tableWidget->item(0, row);
+				horizontalItem->setBackground(tableItemColor);
+				//++i;
+				//row = tableWidget->row(items[i]);
+			}*/
+		
+			QTableWidgetItem *horizontalItem;
+		
+			for (int n=0; n < items.size(); ++n) {
+				//tableWidget->row(i);
+				//Qt::SortOrder order = Qt::AscendingOrder;
+				//tableWidget->sortItems ( column, order);
+				//horizontalHeaderItem = tableWidget->horizontalHeaderItem(column);
+				horizontalItem = Par2->tableWidget->item(Par2->tableWidget->row(items[n]), Par2->tableWidget->column(items[n]));
+				horizontalItem->setBackground(tableItemColor);
+				//++i;
+				//row = tableWidget->row(items[i]);
+			}
+		}
+		
+	}
+	
+	close();
+}
+
 #include "settings_widg.moc"
