@@ -2,8 +2,8 @@
                           utils.h  -  description
                              -------------------
     begin                : December 2007
-    copyright            : (c) 2007 by Roland Suchan
-    email                : vmp@arcor.de
+    copyright            : (c) 2007 by Iven Wold - 526f6c616e642053756368616e
+    email                : hour.glass2@yahoo.com
     license              : GPL v 2.0
  ***************************************************************************/
 
@@ -31,7 +31,7 @@
 #define UTILS_H
 
 #define Q_NAME        "QTrans"
-#define Q_VERSION     "0.2.2.0"
+#define Q_VERSION     "0.2.2.6 - release 7"
 #define Q_DESCRIPTION "QTrans - Instant translator for KDE based on Babylon"
 
 #include <fstream>
@@ -50,33 +50,33 @@ using namespace std;
 	QString reverseString(QString s);
 
 const QString Flag[] = {
-	"<0>",             "flag-be.png",    "flag-bg.png",            "flag-br.png",        "flag-ca.png",
-	"flag-cs.png",     "flag-cy.png",    "flag-da.png",            "flag-de.png",        "flag-el.png",
-	"flag-en.png",     "flag-eo.png",    "flag-es.png",            "flag-et.png",        "flag-eu.png",
-	"flag-fi.png",     "flag-fr.png",    "flag-ga.png",            "flag-gl.png",        "flag-he.png",
-	"flag-hr.png",     "flag-hu.png",    "flag-hy.png",            "flag-id.png",        "flag-is.png",
-	"flag-it.png",     "flag-ja.png",    "flag-ko.png",            "flag-lt.png",        "flag-lv.png",
-	"flag-mi.png",     "flag-mk.png",    "flag-nl.png",            "flag-no.png",        "flag-ph.png",
-	"flag-pl.png",     "flag-pt.png",    "flag-pt_BR.png",         "flag-ro.png",        "flag-ru.png",
-	"flag-sk.png",     "flag-sl.png",    "flag-sp.png",            "flag-sr.png",        "flag-sv.png",
-	"flag-th.png",     "flag-tl.png",    "flag-tr.png",            "flag-uk.png",        "flag-ur.png",
-	"flag-vi.png",     "flag-wa.png",    "flag-zh_CN.GB2312.png",  "flag-zh_CN.png",     "flag-zh_TW.Big5.png",
-	"flag-zh_TW.png",  0L
+	"<0>",			"flag-be.png",		"flag-bg.png",		"flag-br.png",		"flag-ca.png",
+	"flag-cs.png",		"flag-cy.png",		"flag-da.png",		"flag-de.png",		"flag-el.png",
+	"flag-en.png",		"flag-eo.png",		"flag-es.png",		"flag-et.png",		"flag-eu.png",
+	"flag-fi.png",		"flag-fr.png",		"flag-ga.png",		"flag-gl.png",		"flag-he.png",
+	"flag-hr.png",		"flag-hu.png",		"flag-hy.png",		"flag-id.png",		"flag-is.png",
+	"flag-it.png",		"flag-ja.png",		"flag-ko.png",		"flag-lt.png",		"flag-lv.png",
+	"flag-mi.png",		"flag-mk.png",		"flag-nl.png",		"flag-no.png",		"flag-ph.png",
+	"flag-pl.png",		"flag-pt.png",		"flag-pt_BR.png",	"flag-ro.png",		"flag-ru.png",
+	"flag-sk.png",		"flag-sl.png",		"flag-sp.png",		"flag-sr.png",		"flag-sv.png",
+	"flag-th.png",		"flag-tl.png",		"flag-tr.png",		"flag-uk.png",		"flag-ur.png",
+	"flag-vi.png",		"flag-wa.png",		"flag-zh_CN.GB2312.png","flag-zh_CN.png",	"flag-zh_TW.Big5.png",
+	"flag-zh_TW.png",	0L
 };
 
 const QString Language[] = {
-	i18n(" "),         i18n(" "),           i18n(" "),        i18n(" "),        i18n(" "),
-	i18n("Czech"),     i18n(" "),           i18n(" "),        i18n("German"),   i18n("Greek"),
-	i18n("English"),   i18n(" "),           i18n(" "),        i18n(" "),        i18n(" "),
-	i18n(" "),         i18n("French"),      i18n(" "),        i18n(" "),        i18n("Hebrew"),
-	i18n(" "),         i18n("Hungarian"),   i18n(" "),        i18n(" "),        i18n(" "),
-	i18n("Italian"),   i18n("Japanese"),    i18n("Korean"),   i18n(" "),        i18n(" "),
-	i18n(" "),         i18n(" "),           i18n("Dutch"),    i18n(" "),        i18n(" "),
-	i18n("Polish"),    i18n("Portuguese"),  i18n(" "),        i18n(" "),        i18n("Russian"),
-	i18n(" "),         i18n(" "),           i18n("Spanish"),  i18n(" "),        i18n("Swedish"),
-	i18n("Thai"),      i18n(" "),           i18n("Turkish"),  i18n(" "),        i18n(" "),
-	i18n(" "),         i18n(" "),           i18n(" "),        i18n("Chinese"),  i18n(" "),
-	i18n(" "),         0L
+	i18n(" "),		i18n("Belarusian "),	i18n("Bulgarian "),	i18n(" "),		i18n(" "),
+	i18n("Czech"),		i18n(" "),		i18n("Danish"),		i18n("German"),		i18n("Greek"),
+	i18n("English"),	i18n(" "),		i18n("Spanish"),	i18n("Estonian"),	i18n(" "),
+	i18n("Finnish"),	i18n("French"),		i18n(" "),		i18n(" "),		i18n("Hebrew"),
+	i18n("Croatian"),	i18n("Hungarian"),	i18n(" "),		i18n("Indonesian"),	i18n("Icelandic"),
+	i18n("Italian"),	i18n("Japanese"),	i18n("Korean"),		i18n("Lithuanian"),	i18n("Latvian"),
+	i18n(" "),		i18n(" "),		i18n("Dutch"),		i18n("Norvegian"),	i18n("Philippines"),
+	i18n("Polish"),		i18n("Portuguese"),	i18n("Brazilian"),	i18n("Romanian"),	i18n("Russian"),
+	i18n("Slovakian"),	i18n("Slovenian"),	i18n(" "),		i18n("Serbian"),	i18n("Swedish"),
+	i18n("Thai"),		i18n(" "),		i18n("Turkish"),	i18n("Ukrainian"),	i18n("Pakistani"),
+	i18n("Vietnamese"),	i18n(" "),		i18n(" "),		i18n("Chinese"),	i18n(" "),
+	i18n(" "),		0L
 };
 
 const QString Codec[] = {
@@ -85,6 +85,8 @@ const QString Codec[] = {
 	"iso-8859-6",	/*Arabic*/
 	"cp-1257",	/*Baltic*/
 	"iso-8859-13",	/*Baltic*/
+	"iso-8859-2",	/*Central European*/
+	"iso-8859-3",	/*Central European*/
 	"cp-1250",	/*Central European*/
 	"gbk",		/*Chinese Simplified*/
 	"iso-8859-15",	/*Chinese Simplified*/
@@ -105,6 +107,7 @@ const QString Codec[] = {
 	"sjis",		/*Japanese*/
 	"euckr",	/*Korean*/
 
+	"iso-8859-16",	/*South European*/
 	"cp-874",	/*Thai*/
 	"iso-8859-11",	/*Thai*/
 	"cp-1254",	/*Turkish*/
@@ -125,6 +128,8 @@ const QString codecLanguage[] = {
 	"Baltic",
 	"Baltic",
 	"Central European",
+	"Central European",
+	"Central European",
 	"Chinese Simplified",
 	"Chinese Simplified",
 	"Chinese Traditional",
@@ -144,6 +149,7 @@ const QString codecLanguage[] = {
 	"Japanese",
 	"Korean",
 
+	"South European",
 	"Thai",
 	"Thai",
 	"Turkish",
